@@ -50,7 +50,7 @@ class Function:
         parser.add_argument('--replicas', type=int, help='total number of replicas', default='1')
         parser.add_argument('--shards', type=int, help='total number of shards', default='1')
         parser.add_argument('--name', type=str, help='functions name')
-        parser.add_argument('--node_type', type=str, help='type of node to schedule function on')
+        parser.add_argument('--node_type', type=str, help='type of node to schedule function on', default='STANDARD')
 
     def __init__(self,
                  in_sock_type: SocketType = SocketType.PULL,
@@ -139,7 +139,7 @@ class Function:
         """
         :return: Request CPU in 1/1000th of a core
         """
-        return 2000 if self._node_type == NodeType.COMPUTE else 1000
+        return 2000 if self._node_type == NodeType.COMPUTE else 500
 
     @property
     def volume_request(self) -> Optional[int]:
