@@ -10,7 +10,7 @@ import pinecone
 from pinecone.specs import service as service_specs
 from pinecone.functions import Function
 from pinecone.functions.model import HubFunction
-from pinecone.functions.engine import namespaced, accelerated
+from pinecone.functions.engine import namespaced
 from pinecone.functions.ranker import aggregator
 from pinecone.utils.constants import NodeType
 
@@ -109,7 +109,7 @@ class IndexGraph(Graph):
     _default_aggregator = aggregator.Aggregator
 
     def __init__(self, engine_type: str = "approximated", metric: str = "cosine", shards: int = 1, replicas: int = 1,
-                 node_type: NodeType = NodeType.STANDARD):
+                 node_type: NodeType = NodeType.STANDARD, gateway_replicas: int = 1):
         """
 
         :param engine_type: type of engine, one of {"approximated", "exact"}, defaults to "approximated".
@@ -131,8 +131,10 @@ class IndexGraph(Graph):
         :type replicas: int, optional
         :param node_type: type of node to schedule the workloads on e.g. "STANDARD", "COMPUTE"
         :type node_type: NodeType, optional
+        :param gateway_replicas: number of replicas of both the gateway and the aggregator.
+        :type gateway_replicas: int, optional
         """
-        super().__init__()
+        super().__init__(gateway_replicas=gateway_replicas)
         self.preprocessors = {
             "read": [],
             "write": [],
@@ -142,7 +144,8 @@ class IndexGraph(Graph):
         # The engine and the aggregator must be specified for an index service
         self.engine = self._default_engine(engine_type, metric=metric, replicas=replicas, shards=shards,
                                            name="engine", node_type=node_type)
-        self.aggregator = None if shards == 1 else self._default_aggregator(num_shards=shards, name="aggregator")
+        self.aggregator = None if shards == 1 else self._default_aggregator(num_shards=shards, name="aggregator",
+                                                                            replicas=gateway_replicas)
         self._update_graph()
 
     def add_postprocessor(self, image_uri: str = None, config: dict = None, fn: Function = None):
