@@ -10,9 +10,8 @@ from pinecone.utils import open_or_create, get_hostname, wal
 from pinecone.utils.constants import MAX_CLIENTS, SEND_TIMEOUT, ZMQ_LOG_PORT, MAX_MSGS_PENDING
 from pinecone.network.zmq.spec import ServletSpec, SocketType, Socket
 
-from typing import Iterable, Tuple
+from typing import Iterable, Tuple, List
 from loguru import logger
-from ddtrace.contrib.asyncio import run_in_executor
 
 import concurrent.futures
 from threading import Lock
@@ -102,19 +101,15 @@ class WALServlet(ZMQServlet):
 
     async def poll_sock(self, sock: zmq.Socket):
         while True:
-            try:
-                msg = await self.recv_msg(sock)
-                if self.use_wal(msg):
-                    await self.in_msgs.put(msg)
-                else:
-                    await self.handle_msg(msg)
-            except asyncio.TimeoutError:
-                pass
+            msg = await self.recv_msg(sock)
+            if self.use_wal(msg):
+                await self.in_msgs.put(msg)
+            else:
+                await self.handle_msg(msg)
 
-    async def poll(self):
+    def start_polling(self) -> List[asyncio.Task]:
         loop = asyncio.get_event_loop()
-        await asyncio.gather(*(loop.create_task(self.poll_sock(sock)) for sock in self.zmq_ins),
-                             loop.create_task(self.poll_log_socks()))
+        return [*(loop.create_task(self.poll_sock(sock)) for sock in self.zmq_ins), loop.create_task(self.poll_log_socks())]
 
     def use_wal(self, msg: core_pb2.Request) -> bool:
         req_type = msg.WhichOneof('body')
@@ -169,7 +164,8 @@ class WALServlet(ZMQServlet):
                 logger.error("SENDING TIMED OUT, RETRYING")
 
     async def run_sync(self, func, *args, **kwargs):
-        return await run_in_executor(asyncio.get_event_loop(), self.executor, functools.partial(func, *args, **kwargs))
+        loop = asyncio.get_event_loop()
+        return await loop.run_in_executor(self.executor, functools.partial(func, *args, **kwargs))
 
     def get_offset(self, replica: int):
         start = wal.OFFSET_BYTES * replica
@@ -197,7 +193,7 @@ class WALServlet(ZMQServlet):
     def is_next(self, client_id: int, client_offset: int):
         if self.leader:
             if client_offset == 0:
-                self.sync_set_client_offset(client_id, 0)
+                self.sync_set_client_offset(client_id, 0)  # should make this async
             return client_offset == self.get_client_offset(client_id)
         else:
             return True
@@ -223,20 +219,22 @@ class WALServlet(ZMQServlet):
                 # we need to copy the message, because it might get changed later on
                 self.last = core_pb2.Request()
                 self.last.CopyFrom(entry)
-                if self.log_file.tell() > self.wal_size_limit and not self.log_compaction_started:
-                    loop = asyncio.get_event_loop()
-                    loop.create_task(self.start_compact_log())
+                logfile_size = self.log_file.tell()
+            return logfile_size, self.size
 
         elif offset <= self.size:
-            return
+            return self.log_file.tell(), None
         else:
             raise InvalidOffsetException
-        return self.size
 
     async def put(self, item: core_pb2.Request, offset: int = None):
         if not self.leader and offset is None:
             raise RuntimeError(f"{get_hostname()} Attempted to write directly to replica {self.replica} instead of leader")
-        return await self.run_sync(self.sync_put, item, offset)
+        logfile_size, offset = await self.run_sync(self.sync_put, item, offset)
+        if logfile_size > self.wal_size_limit and not self.log_compaction_started:
+            loop = asyncio.get_event_loop()
+            loop.create_task(self.start_compact_log())
+        return offset
 
     def sync_replay_log(self, offset: int, end_offset: int = None) -> Iterable[Tuple[int, core_pb2.Request]]:
         """
@@ -317,7 +315,6 @@ class WALServlet(ZMQServlet):
             os.remove(self.log_path)
             os.rename(self.tmp_log_path, self.log_path)
             self.log_file = open(self.log_path, "r+b")
-            self.log_compaction_started = False
 
     async def start_compact_log(self):
         with self.log_lock:
@@ -329,6 +326,7 @@ class WALServlet(ZMQServlet):
                                    self.log_path, self.tmp_log_path, end_file_offset)
 
         await self.run_sync(self.swap_log_files, end_file_offset)
+        self.log_compaction_started = False
 
     @property
     def all_socks(self):
